@@ -14,9 +14,9 @@ import os
 import typing
 import torch.nn as nn
 from omegaconf import OmegaConf
-from .utils import res_path
-from .models import CLIP, ruCLIP
-from .processor import TextProcessor
+from pytorch_clip.utils import res_path
+from pytorch_clip.models import CLIP, ruCLIP
+from pytorch_clip.processor import TextProcessor
 
 
 def get_models_list() -> typing.List[str]:
@@ -30,20 +30,20 @@ def get_models_list() -> typing.List[str]:
 def get_clip_model(clip_type: str = "clip_vit_b32", input_range: typing.Tuple[float, float] = (-1.0, 1.0), cache_dir: str = "/tmp/") -> typing.Tuple[nn.Module, TextProcessor, nn.Module, OmegaConf]:
     """Build CLIP model from config file.
     Arguments:
-        clip_type (str): type of the CLIP model.
+        cfg (OmegaConf): configuration of the model.
         input_range (tuple[float, float]): input range.
         cache_dir (str): path to cache dir.
     Returns:
         model (nn.Module): CLIP model.
         text_processor (TextProcessor): text processor.
         image_processor (nn.Module): image processor.
-        cfg (OmegaConf):
+        cfg (OmegaConf): configuration of the CLIP model.
     """
     assert clip_type in get_models_list(), f"Unknown clip_type: {clip_type}"
     cfg = OmegaConf.load(res_path(f"configs/{clip_type}.yml"))
     if cfg.type == "clip":
-        return CLIP.from_pretrained(cfg, input_range, cache_dir=cache_dir), cfg
+        return *CLIP.from_pretrained(cfg, input_range, cache_dir=cache_dir), cfg
     elif cfg.type  == "ruclip":
-        return ruCLIP.from_pretrained(cfg, input_range, cache_dir=cache_dir), cfg
+        return *ruCLIP.from_pretrained(cfg, input_range, cache_dir=cache_dir), cfg
     else:
         raise ValueError(f"Unknown model type: {cfg.type}. Available model types: [clip, ruclip]")
